==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/product/products_vpe.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	products_vpe.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'ERROR_REMOVE_DEFAULT_PRODUCTS_VPE' => 'Fehler: Die Standard-Verpackungseinheit kann nicht gelöscht werden. Bitte definieren Sie eine neue Standard-VPE und wiederholen Sie den Vorgang.',
	'ERROR_INVALID_INPUT_FIELDS' => 'Es muss mindestens ein Feld ausgefüllt werden',
	'HEADING_TITLE' => 'Verpackungseinheiten',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_PRODUCTS_VPE' => 'Verpackungseinheit',
	'TEXT_INFO_DELETE_INTRO' => 'Sind Sie sicher, dass Sie diese VPE löschen möchten?',
	'TEXT_INFO_EDIT_INTRO' => 'Bitte führen Sie alle notwendigen Änderungen durch.',
	'TEXT_INFO_INSERT_INTRO' => 'Bitte geben Sie die neue VPE mit allen relevanten Daten ein.',
	'TEXT_INFO_HEADING_DELETE_PRODUCTS_VPE' => 'Verpackungseinheit löschen',
	'TEXT_INFO_HEADING_EDIT_PRODUCTS_VPE' => 'Verpackungseinheit bearbeiten',
	'TEXT_INFO_HEADING_NEW_PRODUCTS_VPE' => 'Neue Verpackungseinheit',
	'TEXT_INFO_PRODUCTS_VPE_NAME' => 'Verpackungseinheit:',
    'TEXT_INFO_ADD_SUCCESS' => 'Verpackungseinheit hinzugefügt',
    'TEXT_INFO_DELETE_SUCCESS' => 'Die Verpackungseinheit wurde gelöscht',
    'TEXT_INFO_EDIT_SUCCESS' => 'Die Verpackungseinheit ist bearbeitet worden',
    'TEXT_INFO_CAN_NOT_DELETE_DEFAULT' => 'Die Standard Verpackungseinheit kann nicht gelöscht werden'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/product/products_vpe.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	products_vpe.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'ERROR_REMOVE_DEFAULT_PRODUCTS_VPE' => 'Fehler: Die Standard-Verpackungseinheit kann nicht gelöscht werden. Bitte definiere eine neue Standard-VPE und wiederhole den Vorgang.',
	'ERROR_INVALID_INPUT_FIELDS' => 'Es muss mindestens ein Feld ausgefüllt werden',
	'HEADING_TITLE' => 'Verpackungseinheiten',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_PRODUCTS_VPE' => 'Verpackungseinheit',
	'TEXT_INFO_DELETE_INTRO' => 'Bist du sicher, dass du diese VPE löschen möchtest?',
	'TEXT_INFO_EDIT_INTRO' => 'Bitte führe alle notwendigen Änderungen durch.',
	'TEXT_INFO_INSERT_INTRO' => 'Bitte gib die neue VPE mit allen relevanten Daten ein.',
	'TEXT_INFO_HEADING_DELETE_PRODUCTS_VPE' => 'Verpackungseinheit löschen',
	'TEXT_INFO_HEADING_EDIT_PRODUCTS_VPE' => 'Verpackungseinheit bearbeiten',
	'TEXT_INFO_HEADING_NEW_PRODUCTS_VPE' => 'Neue Verpackungseinheit',
	'TEXT_INFO_PRODUCTS_VPE_NAME' => 'Verpackungseinheit:',
    'TEXT_INFO_ADD_SUCCESS' => 'Verpackungseinheit hinzugefügt',
    'TEXT_INFO_DELETE_SUCCESS' => 'Die Verpackungseinheit wurde gelöscht',
    'TEXT_INFO_EDIT_SUCCESS' => 'Die Verpackungseinheit ist bearbeitet worden',
    'TEXT_INFO_CAN_NOT_DELETE_DEFAULT' => 'Die Standard Verpackungseinheit kann nicht gelöscht werden'
);
